@@ -85,18 +85,20 @@ public:
 };
 
 
-// Elliptic Curve Secret Key
-class ECSecKey {
+// Elliptic Curve Private Key
+class ECPrivKey {
 public:
 	EC_Domain_Parameters dp;
-	BigInt s; // the secret key
+	BigInt s; // the private key
 
-	ECSecKey (const EC_Domain_Parameters& ecdp); // generate a random secret key
-	ECSecKey (const EC_Domain_Parameters& ecdp, const BigInt& ecs);
+	ECPrivKey (const EC_Domain_Parameters& ecdp); // generate a random private key
+	ECPrivKey (const EC_Domain_Parameters& ecdp, const BigInt& ecs);
 
-	ECSecKey& operator= (const ECSecKey& kp);
+	ECPrivKey& operator= (const ECPrivKey& kp);
 };
 
+#define ECSecKey ECPrivKey	// Deprecated - only for compatibility with old code
+
 
 // Elliptic Curve Public Key
 class ECPubKey {
@@ -105,7 +107,7 @@ public:
 	Point W; // the public key
 
 	inline ECPubKey () {};
-	ECPubKey (const ECSecKey& sk);
+	ECPubKey (const ECPrivKey& sk);
 	ECPubKey (const EC_Domain_Parameters& dp, const Point& W);
 
 	bool valid (); // return true iff the public key is valid
@@ -165,7 +167,7 @@ public:
 
 	inline ECDSA () {}
 	ECDSA (const BigInt& cval, const BigInt& dval);
-	ECDSA (const ECSecKey& sk, const BigInt& f);
+	ECDSA (const ECPrivKey& sk, const BigInt& f);
 	bool verify (const ECPubKey& pk, const BigInt& f);
 	std::ostream& put (std::ostream&s) const;
 	ECDSA& operator= (const ECDSA& esig);
@@ -182,7 +184,7 @@ public:
 	inline ECIES () {}
 	inline ECIES (ECPubKey V_val, OCTETSTR C_val, OCTETSTR T_val) { V=V_val; C=C_val; T=T_val;}
 	ECIES (OCTETSTR& M, ECPubKey& pk);
-	OCTETSTR decrypt (ECSecKey& sk); // Throws borzoiException if the tag is invalid
+	OCTETSTR decrypt (ECPrivKey& sk); // Throws borzoiException if the tag is invalid
 	std::ostream& put (std::ostream&s) const;
 };
 
@@ -191,13 +193,15 @@ public:
 class DER : public borZoi {
 public:
 	inline DER (OCTETSTR vin) { v=vin; } // set v = to vin
+	DER (EC_Domain_Parameters dp);
 	DER (ECPubKey pk); // encode a public key
-	DER (ECSecKey sk); // encode a secret key
+	DER (ECPrivKey sk); // encode a private key
 	DER (ECDSA sig); // encode a signature
 	DER (ECIES ct); // encode an ECIES ciphertext (non-standard)
 
+	EC_Domain_Parameters toECDP ();
 	ECPubKey toECPubKey (); // convert a DER string to an EC public key
-	ECSecKey toECSecKey (); // convert a DER string to an EC secret key
+	ECPrivKey toECPrivKey (); // convert a DER string to an EC private key
 	ECDSA toECDSA (); // convert a DER string to an ECDSA signature
 	ECIES toECIES (); // convert a DER string to an ECIES ciphertext (non-standard)
 	DER& operator= (const DER& d);
