@@ -88,7 +88,7 @@ OCTETSTR I2OSP (BigInt i);
 
 inline BigInt FE2IP (F2M j) { return OS2IP (FE2OSP(j)); }
 
-F2M I2FEP (BigInt z); //FIXME may need to be replaced by the P1363 spec primitives
+F2M I2FEP (BigInt z);
 
 
 BigInt operator|| (const BigInt& a, const BigInt& b); // concantenate two BigInts
